==> _private_chat-1.3.16.tar.gz: lib/utils/utils.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../chat_detail/chat_helper.dart';
import '../constant.dart';
import '../firestore_resouce/instances.dart';

int getTimestamp(data) => data[kDbTIMESTAMP];

String getContent(key, data) => ChatHelper.decrypt(key, data[kDbCONTENT]);

bool getIsMe(data) => data[kDbFROM] == loggedFirebaseId;

bool get isLogged => appPrefs.loginUser != null;

String get loggedUsername => appPrefs.loginUser?.username ?? '';

String get loggedFirebaseId => appPrefs.loginUser?.firebaseId ?? '';

Future<Map> getStatisticFirstMessage(int platformId) async {
  QuerySnapshot q = await colCONVERSATIONS
      .where(kDbMEMBERSFIREBASEID, arrayContains: loggedFirebaseId)
      .orderBy(kDbLASTMESSAGETIME, descending: true)
      .get();
  var totalfirstMessage = 0;
  var totalfirstMessageAnswer = 0;
  var totalfirstMessageAnswerTime = 0;
  for (var d in q.docs) {
    Map docData = d.data() as Map;
    if (docData['firstMessage'] != null &&
        docData['firstMessage'][kDbPLATFORMID] == platformId) {
      totalfirstMessage++;

      if (docData['firstMessageAnswer'] != null &&
          docData['firstMessageAnswer'][kDbFROM] == loggedFirebaseId) {
        totalfirstMessageAnswerTime += (docData['firstMessageAnswer']
                [kDbTIMESTAMP] as int) -(
            docData['firstMessage'][kDbTIMESTAMP] as int);
        totalfirstMessageAnswer++;
      }
    }
  }  
  var result = {
    //in miliseconds
    "averageTimeResponse": totalfirstMessageAnswerTime/ totalfirstMessageAnswer,
    "totalfirstMessage": totalfirstMessage,
    "pourcentageMessageResponse": ((totalfirstMessageAnswer / totalfirstMessage) * 100)
  };
  return result;
}

==> _private_chat-1.3.18.tar.gz: lib/utils/utils.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:cloud_firestore/cloud_firestore.dart';
import '../chat_detail/chat_helper.dart';
import '../constant.dart';
import '../firestore_resouce/instances.dart';

int getTimestamp(data) => data[kDbTIMESTAMP];

String getContent(key, data) => ChatHelper.decrypt(key, data[kDbCONTENT]);

bool getIsMe(data) => data[kDbFROM] == loggedFirebaseId;

bool get isLogged => appPrefs.loginUser != null;

String get loggedUsername => appPrefs.loginUser?.username ?? '';

String get loggedFirebaseId => appPrefs.loginUser?.firebaseId ?? '';

Future<Map> getStatisticFirstMessage(int platformId) async {
  QuerySnapshot q = await colCONVERSATIONS
      .where(kDbMEMBERSFIREBASEID, arrayContains: loggedFirebaseId)
      .orderBy(kDbLASTMESSAGETIME, descending: true)
      .get();
  var totalfirstMessage = 0;
  var totalfirstMessageAnswer = 0;
  var totalfirstMessageAnswerTime = 0;
  for (var d in q.docs) {
    Map docData = d.data() as Map;
    if (docData['firstMessage'] != null &&
        docData['firstMessage'][kDbPLATFORMID] == platformId) {
      totalfirstMessage++;

      if (docData['firstMessageAnswer'] != null &&
          docData['firstMessageAnswer'][kDbFROM] == loggedFirebaseId) {
        totalfirstMessageAnswerTime +=
            (docData['firstMessageAnswer'][kDbTIMESTAMP] as int) -
                (docData['firstMessage'][kDbTIMESTAMP] as int);
        totalfirstMessageAnswer++;
      }
    }
  }
  var result = {
    //in miliseconds
    "averageTimeResponse": totalfirstMessageAnswer == 0
        ? 0
        : totalfirstMessageAnswerTime / totalfirstMessageAnswer,
    "totalfirstMessage": totalfirstMessage,
    "pourcentageMessageResponse": totalfirstMessage == 0
        ? 0
        : ((totalfirstMessageAnswer / totalfirstMessage) * 100)
  };
  return result;
}
